@@ -248,6 +248,7 @@ class SimulatorModelRevisionsAPI(APIClient):
             Create new simulator model revisions:
                 >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes.simulators import SimulatorModelRevisionWrite
+                >>> from cognite.client.data_classes.simulators.models import SimulatorExternalDependencyFileInternalId, SimulatorModelRevisionExternalDependency
                 >>> client = CogniteClient()
                 >>> revisions = [
                 ...     SimulatorModelRevisionWrite(
@@ -259,6 +260,15 @@ class SimulatorModelRevisionsAPI(APIClient):
                 ...         external_id="revision2",
                 ...         file_id=2,
                 ...         model_external_id="a_2",
+                ...         external_dependencies = [
+                ...             SimulatorModelRevisionExternalDependency(
+                ...                 file=SimulatorExternalDependencyFileInternalId(id=123),
+                ...                 arguments={
+                ...                     "fieldA": "value1",
+                ...                     "fieldB": "value2",
+                ...                 },
+                ...             )
+                ...         ]
                 ...     ),
                 ... ]
                 >>> res = client.simulators.models.revisions.create(revisions)
