@@ -876,10 +876,10 @@ class WorkflowAPI(APIClient):
         return self()
 
     @overload
-    def upsert(self, workflow: WorkflowUpsert) -> Workflow: ...
+    def upsert(self, workflow: WorkflowUpsert, mode: Literal["replace"] = "replace") -> Workflow: ...
 
     @overload
-    def upsert(self, workflow: Sequence[WorkflowUpsert]) -> WorkflowList: ...
+    def upsert(self, workflow: Sequence[WorkflowUpsert], mode: Literal["replace"] = "replace") -> WorkflowList: ...
 
     def upsert(
         self, workflow: WorkflowUpsert | Sequence[WorkflowUpsert], mode: Literal["replace"] = "replace"
@@ -923,10 +923,10 @@ class WorkflowAPI(APIClient):
         )
 
     @overload
-    def retrieve(self, external_id: str) -> Workflow | None: ...
+    def retrieve(self, external_id: str, ignore_unknown_ids: bool = False) -> Workflow | None: ...
 
     @overload
-    def retrieve(self, external_id: SequenceNotStr[str]) -> WorkflowList: ...
+    def retrieve(self, external_id: SequenceNotStr[str], ignore_unknown_ids: bool = False) -> WorkflowList: ...
 
     def retrieve(
         self, external_id: str | SequenceNotStr[str], ignore_unknown_ids: bool = False
