@@ -291,6 +291,8 @@ from cognite.client.data_classes.workflows import (
     DynamicTaskParameters,
     FunctionTaskOutput,
     FunctionTaskParameters,
+    SimulationTaskOutput,
+    SimulationTaskParameters,
     SubworkflowTaskParameters,
     TransformationTaskOutput,
     TransformationTaskParameters,
@@ -320,118 +322,195 @@ from cognite.client.data_classes.workflows import (
 )
 
 __all__ = [
+    "ALL_USER_ACCOUNTS",
+    "AggregateResult",
+    "AggregateResultItem",
+    "AggregateUniqueValuesResult",
     "Annotation",
+    "AnnotationFilter",
+    "AnnotationList",
+    "AnnotationReverseLookupFilter",
+    "AnnotationUpdate",
     "AnnotationWrite",
     "AnnotationWriteList",
-    "AnnotationFilter",
-    "AnnotationReverseLookupFilter",
-    "AnnotationList",
-    "AnnotationUpdate",
-    "AggregateResultItem",
     "Asset",
-    "AssetWrite",
-    "CountAggregate",
     "AssetFilter",
     "AssetHierarchy",
     "AssetList",
-    "AssetWriteList",
     "AssetUpdate",
+    "AssetWrite",
+    "AssetWriteList",
+    "BoundingBox3D",
+    "CDFTaskOutput",
+    "CDFTaskParameters",
+    "ClientCredentials",
+    "ConstantResolver",
     "ContextualizationJob",
     "ContextualizationJobList",
     "ContextualizationJobType",
+    "CoordinateReferenceSystem",
+    "CoordinateReferenceSystemList",
+    "CoordinateReferenceSystemWrite",
+    "CoordinateReferenceSystemWriteList",
+    "CountAggregate",
+    "CreatedSession",
+    "DataPointSubscriptionCreate",
+    "DataPointSubscriptionUpdate",
+    "DataPointSubscriptionWrite",
+    "DataSet",
+    "DataSetFilter",
+    "DataSetList",
+    "DataSetUpdate",
+    "DataSetWrite",
+    "DataSetWriteList",
+    "Database",
+    "DatabaseList",
+    "DatabaseWrite",
+    "DatabaseWriteList",
+    "Datapoint",
+    "DatapointSubscription",
+    "DatapointSubscriptionList",
+    "DatapointSubscriptionWriteList",
+    "Datapoints",
+    "DatapointsArray",
+    "DatapointsArrayList",
+    "DatapointsList",
+    "DatapointsQuery",
+    "Document",
+    "DocumentHighlight",
+    "DocumentHighlightList",
+    "DocumentList",
+    "DynamicTaskOutput",
+    "DynamicTaskParameters",
+    "EndTimeFilter",
     "EntityMatchingModel",
     "EntityMatchingModelList",
     "EntityMatchingModelUpdate",
-    "JobStatus",
-    "Database",
-    "DatabaseWrite",
-    "DatabaseList",
-    "DatabaseWriteList",
-    "Row",
-    "RowWrite",
-    "RowList",
-    "RowWriteList",
-    "Table",
-    "TableWrite",
-    "TableList",
-    "TableWriteList",
+    "Event",
+    "EventFilter",
+    "EventList",
+    "EventUpdate",
+    "EventWrite",
+    "EventWriteList",
     "ExtractionPipeline",
-    "ExtractionPipelineWrite",
-    "ExtractionPipelineWriteList",
     "ExtractionPipelineConfig",
-    "ExtractionPipelineConfigWrite",
     "ExtractionPipelineConfigRevision",
     "ExtractionPipelineConfigRevisionList",
+    "ExtractionPipelineConfigWrite",
     "ExtractionPipelineConfigWriteList",
     "ExtractionPipelineContact",
     "ExtractionPipelineList",
     "ExtractionPipelineRun",
-    "ExtractionPipelineRunWrite",
     "ExtractionPipelineRunFilter",
     "ExtractionPipelineRunList",
+    "ExtractionPipelineRunWrite",
     "ExtractionPipelineRunWriteList",
     "ExtractionPipelineUpdate",
-    "EndTimeFilter",
-    "Event",
-    "EventWrite",
-    "EventFilter",
-    "EventList",
-    "EventWriteList",
-    "EventUpdate",
+    "ExtractionPipelineWrite",
+    "ExtractionPipelineWriteList",
+    "Feature",
+    "FeatureAggregate",
+    "FeatureAggregateList",
+    "FeatureList",
+    "FeatureType",
+    "FeatureTypeList",
+    "FeatureTypePatch",
+    "FeatureTypeWrite",
+    "FeatureTypeWriteList",
+    "FeatureWrite",
+    "FeatureWriteList",
     "FileMetadata",
-    "FileMetadataWrite",
     "FileMetadataFilter",
     "FileMetadataList",
-    "FileMetadataWriteList",
     "FileMetadataUpdate",
+    "FileMetadataWrite",
+    "FileMetadataWriteList",
     "FileMultipartUploadSession",
-    "SourceFile",
-    "Document",
-    "DocumentList",
-    "DocumentHighlight",
-    "DocumentHighlightList",
-    "ClientCredentials",
-    "ALL_USER_ACCOUNTS",
-    "CreatedSession",
+    "Function",
+    "FunctionCall",
+    "FunctionCallList",
+    "FunctionCallLog",
+    "FunctionCallLogEntry",
+    "FunctionFilter",
+    "FunctionList",
+    "FunctionSchedule",
+    "FunctionScheduleWrite",
+    "FunctionScheduleWriteList",
+    "FunctionSchedulesFilter",
+    "FunctionSchedulesList",
+    "FunctionTaskOutput",
+    "FunctionTaskParameters",
+    "FunctionWrite",
+    "FunctionWriteList",
+    "FunctionsLimits",
+    "GeoLocation",
+    "GeoLocationFilter",
+    "Geometry",
+    "GeometryFilter",
     "Group",
-    "GroupWrite",
     "GroupList",
+    "GroupWrite",
     "GroupWriteList",
-    "SecurityCategory",
-    "SecurityCategoryWrite",
-    "SecurityCategoryList",
-    "SecurityCategoryWriteList",
-    "Session",
-    "SessionList",
+    "HasExternalAndInternalId",
+    "HasExternalAndInternalId",
+    "HasExternalId",
+    "HasExternalId",
+    "HasInternalId",
+    "HasInternalId",
+    "HasName",
+    "HasName",
+    "JobStatus",
     "Label",
     "LabelDefinition",
-    "LabelDefinitionWrite",
     "LabelDefinitionFilter",
     "LabelDefinitionList",
+    "LabelDefinitionWrite",
     "LabelFilter",
+    "LatestDatapointQuery",
+    "OidcCredentials",
+    "RawTable",
     "Relationship",
-    "RelationshipWrite",
     "RelationshipFilter",
     "RelationshipList",
-    "RelationshipWriteList",
     "RelationshipUpdate",
+    "RelationshipWrite",
+    "RelationshipWriteList",
+    "RevisionCameraProperties",
+    "Row",
+    "RowList",
+    "RowWrite",
+    "RowWriteList",
+    "SecurityCategory",
+    "SecurityCategoryList",
+    "SecurityCategoryWrite",
+    "SecurityCategoryWriteList",
     "Sequence",
-    "SequenceWrite",
+    "SequenceColumn",
+    "SequenceColumnList",
     "SequenceColumnUpdate",
+    "SequenceColumnWrite",
+    "SequenceColumnWriteList",
     "SequenceData",
-    "SequenceRows",
-    "SequenceRowsList",
     "SequenceFilter",
     "SequenceList",
-    "SequenceWriteList",
-    "SequenceUpdate",
-    "SequenceColumn",
-    "SequenceColumnWrite",
-    "SequenceColumnList",
-    "SequenceColumnWriteList",
     "SequenceRow",
-    "ConstantResolver",
+    "SequenceRows",
+    "SequenceRowsList",
+    "SequenceUpdate",
+    "SequenceWrite",
+    "SequenceWriteList",
+    "Session",
+    "SessionList",
+    "SimulationTaskOutput",
+    "SimulationTaskParameters",
     "Source",
+    "SourceFile",
+    "StatusCode",
+    "SubworkflowTaskParameters",
+    "Table",
+    "TableList",
+    "TableWrite",
+    "TableWriteList",
     "TemplateGroup",
     "TemplateGroupList",
     "TemplateGroupVersion",
@@ -439,153 +518,82 @@ __all__ = [
     "TemplateInstance",
     "TemplateInstanceList",
     "TemplateInstanceUpdate",
-    "View",
-    "ViewResolver",
-    "BoundingBox3D",
-    "RevisionCameraProperties",
     "ThreeDAssetMapping",
-    "ThreeDAssetMappingWrite",
     "ThreeDAssetMappingList",
+    "ThreeDAssetMappingWrite",
     "ThreeDAssetMappingWriteList",
     "ThreeDModel",
-    "ThreeDModelWrite",
     "ThreeDModelList",
-    "ThreeDModelWriteList",
     "ThreeDModelRevision",
-    "ThreeDModelRevisionWrite",
     "ThreeDModelRevisionList",
-    "ThreeDModelRevisionWriteList",
     "ThreeDModelRevisionUpdate",
+    "ThreeDModelRevisionWrite",
+    "ThreeDModelRevisionWriteList",
     "ThreeDModelUpdate",
+    "ThreeDModelWrite",
+    "ThreeDModelWriteList",
     "ThreeDNode",
     "ThreeDNodeList",
     "TimeSeries",
-    "TimeSeriesWrite",
     "TimeSeriesFilter",
     "TimeSeriesList",
-    "TimeSeriesWriteList",
     "TimeSeriesUpdate",
-    "DatapointSubscription",
-    "DataPointSubscriptionWrite",
-    "DataPointSubscriptionCreate",
-    "DatapointSubscriptionList",
-    "DataPointSubscriptionUpdate",
-    "DatapointSubscriptionWriteList",
-    "OidcCredentials",
-    "RawTable",
+    "TimeSeriesWrite",
+    "TimeSeriesWriteList",
+    "TimestampRange",
     "Transformation",
-    "TransformationWrite",
     "TransformationBlockedInfo",
     "TransformationDestination",
-    "TransformationList",
-    "TransformationWriteList",
-    "TransformationPreviewResult",
-    "TransformationUpdate",
     "TransformationJob",
     "TransformationJobFilter",
     "TransformationJobList",
     "TransformationJobMetric",
     "TransformationJobMetricList",
     "TransformationJobStatus",
+    "TransformationList",
     "TransformationNotification",
     "TransformationNotificationList",
     "TransformationNotificationWrite",
     "TransformationNotificationWriteList",
+    "TransformationPreviewResult",
     "TransformationSchedule",
-    "TransformationScheduleWrite",
     "TransformationScheduleList",
-    "TransformationScheduleWriteList",
     "TransformationScheduleUpdate",
+    "TransformationScheduleWrite",
+    "TransformationScheduleWriteList",
     "TransformationSchemaColumn",
     "TransformationSchemaColumnList",
-    "DataSet",
-    "DataSetWrite",
-    "DataSetFilter",
-    "DataSetList",
-    "DataSetWriteList",
-    "DataSetUpdate",
-    "AggregateResult",
-    "AggregateUniqueValuesResult",
-    "GeoLocation",
-    "GeoLocationFilter",
-    "GeometryFilter",
-    "Geometry",
-    "TimestampRange",
-    "Datapoint",
-    "Datapoints",
-    "DatapointsList",
-    "DatapointsArray",
-    "DatapointsArrayList",
-    "DatapointsQuery",
-    "LatestDatapointQuery",
-    "StatusCode",
-    "Function",
-    "FunctionWrite",
-    "FunctionFilter",
-    "FunctionSchedule",
-    "FunctionScheduleWrite",
-    "FunctionSchedulesFilter",
-    "FunctionScheduleWriteList",
-    "FunctionSchedulesList",
-    "FunctionList",
-    "FunctionWriteList",
-    "FunctionCall",
-    "FunctionCallList",
-    "FunctionCallLogEntry",
-    "FunctionCallLog",
-    "FunctionsLimits",
-    "Feature",
-    "FeatureWrite",
-    "FeatureList",
-    "FeatureWriteList",
-    "FeatureType",
-    "FeatureTypeWrite",
-    "FeatureTypeList",
-    "FeatureTypeWriteList",
-    "FeatureTypePatch",
-    "FeatureAggregate",
-    "FeatureAggregateList",
-    "CoordinateReferenceSystemList",
-    "CoordinateReferenceSystemWrite",
-    "CoordinateReferenceSystemWriteList",
-    "CoordinateReferenceSystem",
+    "TransformationTaskOutput",
+    "TransformationTaskParameters",
+    "TransformationUpdate",
+    "TransformationWrite",
+    "TransformationWriteList",
     "UserProfile",
     "UserProfileList",
-    "WorkflowUpsert",
+    "View",
+    "ViewResolver",
+    "Workflow",
+    "WorkflowDefinition",
+    "WorkflowDefinitionUpsert",
     "WorkflowExecution",
     "WorkflowExecutionDetailed",
     "WorkflowExecutionList",
     "WorkflowList",
-    "WorkflowVersion",
-    "WorkflowVersionUpsert",
-    "WorkflowVersionId",
-    "WorkflowVersionList",
-    "FunctionTaskParameters",
-    "TransformationTaskParameters",
-    "CDFTaskParameters",
-    "DynamicTaskParameters",
-    "SubworkflowTaskParameters",
-    "FunctionTaskOutput",
-    "TransformationTaskOutput",
-    "CDFTaskOutput",
-    "DynamicTaskOutput",
-    "WorkflowDefinition",
-    "WorkflowDefinitionUpsert",
-    "WorkflowTaskExecution",
-    "Workflow",
     "WorkflowTask",
-    "WorkflowUpsertList",
-    "WorkflowVersionUpsertList",
-    "WorkflowVersionUpsertList",
+    "WorkflowTaskExecution",
     "WorkflowTrigger",
     "WorkflowTriggerCreate",
-    "WorkflowTriggerUpsert",
     "WorkflowTriggerList",
-    "WorkflowTriggerUpsertList",
     "WorkflowTriggerRun",
     "WorkflowTriggerRunList",
-    "HasName",
-    "HasExternalId",
-    "HasInternalId",
-    "HasExternalAndInternalId",
+    "WorkflowTriggerUpsert",
+    "WorkflowTriggerUpsertList",
+    "WorkflowUpsert",
+    "WorkflowUpsertList",
+    "WorkflowVersion",
+    "WorkflowVersionId",
+    "WorkflowVersionList",
+    "WorkflowVersionUpsert",
+    "WorkflowVersionUpsertList",
+    "WorkflowVersionUpsertList",
 ]
