@@ -36,6 +36,7 @@ from typing_extensions import Self
 
 from cognite.client.data_classes._base import (
     CogniteObject,
+    CogniteResource,
     CogniteResourceList,
     T_CogniteResource,
     T_WriteClass,
@@ -232,8 +233,7 @@ class Properties(MutableMapping[ViewIdentifier, MutableMapping[PropertyIdentifie
                 view_tuple = tuple(view_id_str.split("/", 1))
                 if len(view_tuple) != 2:
                     warnings.warn(
-                        f"Unknown type of view id: {view_id_str}, expected format <external_id>/<version>. "
-                        "Skipping...",
+                        f"Unknown type of view id: {view_id_str}, expected format <external_id>/<version>. Skipping...",
                         stacklevel=2,
                     )
                     continue
@@ -427,7 +427,7 @@ class Instance(WritableInstanceCore[T_CogniteResource], ABC):
             camel_case (bool): Convert attribute names to camel case (e.g. `externalId` instead of `external_id`). Does not affect properties if expanded.
             convert_timestamps (bool): Convert known attributes storing CDF timestamps (milliseconds since epoch) to datetime. Does not affect properties.
             expand_properties (bool): Expand the properties into separate rows. Note: Will change default to True in the next major version.
-            remove_property_prefix (bool): Remove view ID prefix from row names of expanded properties (in index). Requires data to be from a single view.
+            remove_property_prefix (bool): Attempt to remove the view ID prefix from row names of expanded properties (in index). Requires data to be from a single view and that all property names do not conflict with base properties (e.g. 'space' or 'type'). In such cases, a warning is issued and the prefix is kept.
             **kwargs (Any): For backwards compatibility.
 
         Returns:
@@ -454,10 +454,20 @@ class Instance(WritableInstanceCore[T_CogniteResource], ABC):
             view_id, *extra = self.properties.keys()
             # We only do/allow this if we have a single source:
             if not extra:
-                prop_df.columns = prop_df.columns.str.removeprefix("{}.{}/{}.".format(*view_id.as_tuple()))
+                prefix = "{}.{}/{}.".format(*view_id.as_tuple())
+                prop_df.columns = prop_df.columns.str.removeprefix(prefix)
+
                 if isinstance(self, TypedInstance):
                     attr_name_mapping = self._get_descriptor_property_name_mapping()
                     prop_df = prop_df.rename(columns=attr_name_mapping)
+
+                if any(overlapping := col.index.intersection(prop_df.columns)):
+                    warnings.warn(
+                        "One or more expanded property names overlapped with base properties. "
+                        f"These rows (index) will not have their view ID prefix removed: {sorted(overlapping)}",
+                        RuntimeWarning,
+                    )
+                    prop_df = prop_df.rename(columns={col: f"{prefix}{col}" for col in overlapping})
             else:
                 warnings.warn(
                     "Can't remove view ID prefix from expanded property rows as source was not unique",
@@ -516,15 +526,14 @@ class InstanceAggregationResult(DataModelingResource):
     @classmethod
     def _load(cls, resource: dict, cognite_client: CogniteClient | None = None) -> Self:
         """
-        Loads an instance from a json string or dictionary.
+        Loads an instance aggregation result from a json string or dictionary.
 
         Args:
             resource (dict): No description.
             cognite_client (CogniteClient | None): No description.
 
         Returns:
-            Self: An instance.
-
+            Self: An instance aggregation result.
         """
         return cls(
             aggregates=[AggregatedNumberedValue.load(agg) for agg in resource["aggregates"]],
@@ -552,6 +561,93 @@ class InstanceAggregationResultList(CogniteResourceList[InstanceAggregationResul
     _RESOURCE = InstanceAggregationResult
 
 
+class InspectionResults(CogniteResource):
+    def __init__(self, involved_views: list[ViewId] | None, involved_containers: list[ContainerId] | None) -> None:
+        self.involved_views = involved_views
+        self.involved_containers = involved_containers
+
+    @classmethod
+    def _load(cls, resource: dict, cognite_client: CogniteClient | None = None) -> Self:
+        involved_views = (
+            [ViewId.load(vid) for vid in resource["involvedViews"]] if "involvedViews" in resource else None
+        )
+        involved_containers = (
+            [ContainerId.load(cid) for cid in resource["involvedContainers"]]
+            if "involvedContainers" in resource
+            else None
+        )
+        return cls(
+            involved_views=involved_views,
+            involved_containers=involved_containers,
+        )
+
+    def dump(self, camel_case: bool = True) -> dict[str, Any]:
+        results = {}
+        if self.involved_views:
+            results["involvedViews" if camel_case else "involved_views"] = [
+                vid.dump(camel_case, include_type=True) for vid in self.involved_views
+            ]
+        if self.involved_containers:
+            results["involvedContainers" if camel_case else "involved_containers"] = [
+                cid.dump(camel_case, include_type=True) for cid in self.involved_containers
+            ]
+        return results
+
+
+@dataclass
+class InspectOperation(ABC): ...
+
+
+@dataclass
+class InvolvedContainers(InspectOperation): ...
+
+
+@dataclass
+class InvolvedViews(InspectOperation):
+    all_versions: bool = False
+
+
+class InstanceInspectResult(CogniteResource):
+    def __init__(
+        self,
+        space: str,
+        external_id: str,
+        instance_type: Literal["node", "edge"],
+        inspection_results: InspectionResults,
+    ) -> None:
+        self.space = space
+        self.external_id = external_id
+        self.instance_type = instance_type
+        self.inspection_results = inspection_results
+
+    @classmethod
+    def _load(cls, resource: dict, cognite_client: CogniteClient | None = None) -> Self:
+        return cls(
+            space=resource["space"],
+            external_id=resource["externalId"],
+            instance_type=resource["instanceType"],
+            inspection_results=InspectionResults.load(resource["inspectionResults"]),
+        )
+
+    def dump(self, camel_case: bool = True) -> dict[str, Any]:
+        return {
+            "space": self.space,
+            "externalId" if camel_case else "external_id": self.external_id,
+            "instanceType" if camel_case else "instance_type": self.instance_type,
+            "inspectionResults" if camel_case else "inspection_results": self.inspection_results.dump(camel_case),
+        }
+
+
+class InstanceInspectResultList(CogniteResourceList[InstanceInspectResult]):
+    _RESOURCE = InstanceInspectResult
+
+
+@dataclass
+class InstanceInspectResults:
+    nodes: InstanceInspectResultList
+    edges: InstanceInspectResultList
+
+
 class NodeApply(InstanceApply["NodeApply"]):
     """A node. This is the write version of the node.
 
@@ -977,7 +1073,7 @@ class DataModelingInstancesList(WriteableCogniteResourceList[T_WriteClass, T_Ins
 
         if isinstance(instance_id, InstanceId):
             instance_id = instance_id.as_tuple()
-        return self._instance_id_to_item.get(instance_id)  # type: ignore [arg-type]
+        return self._instance_id_to_item.get(instance_id)
 
     def extend(self, other: Iterable[Any]) -> None:
         other_res_list = type(self)(other)  # See if we can accept the types
@@ -1002,7 +1098,7 @@ class DataModelingInstancesList(WriteableCogniteResourceList[T_WriteClass, T_Ins
             camel_case (bool): Convert column names to camel case (e.g. `externalId` instead of `external_id`). Does not apply to properties.
             convert_timestamps (bool): Convert known columns storing CDF timestamps (milliseconds since epoch) to datetime. Does not affect properties.
             expand_properties (bool): Expand the properties into separate columns. Note: Will change default to True in the next major version.
-            remove_property_prefix (bool): Remove view ID prefix from columns names of expanded properties. Requires data to be from a single view.
+            remove_property_prefix (bool): Attempt to remove the view ID prefix from columns names of expanded properties. Requires data to be from a single view and that all property names do not conflict with base properties (e.g. 'space' or 'type'). In such cases, a warning is issued and the prefix is kept.
             **kwargs (Any): For backwards compatibility.
 
         Returns:
@@ -1020,16 +1116,27 @@ class DataModelingInstancesList(WriteableCogniteResourceList[T_WriteClass, T_Ins
         if not expand_properties or "properties" not in df.columns:
             return df
 
-        prop_df = local_import("pandas").json_normalize(df.pop("properties"), max_level=2)
+        pd = local_import("pandas")
+        prop_df = pd.json_normalize(df.pop("properties"), max_level=2)
         if remove_property_prefix and not prop_df.empty:
             typed_view_ids = {item.get_source() for item in self if isinstance(item, TypedInstance)}  # type: ignore [attr-defined]
             view_id, *extra = typed_view_ids | set(vid for item in self for vid in item.properties)
             # We only do/allow this if we have a single source:
             if not extra:
-                prop_df.columns = prop_df.columns.str.removeprefix("{}.{}/{}.".format(*view_id.as_tuple()))
+                prefix = "{}.{}/{}.".format(*view_id.as_tuple())
+                prop_df.columns = prop_df.columns.str.removeprefix(prefix)
+
                 if len(self) > 0 and isinstance(self[0], TypedInstance):
                     attr_name_mapping = self[0]._get_descriptor_property_name_mapping()
                     prop_df = prop_df.rename(columns=attr_name_mapping)
+
+                if any(overlapping := df.columns.intersection(prop_df.columns)):
+                    warnings.warn(
+                        "One or more expanded property names overlapped with base properties. "
+                        f"These columns will not have their view ID prefix removed: {sorted(overlapping)}",
+                        RuntimeWarning,
+                    )
+                    prop_df = prop_df.rename(columns={col: f"{prefix}{col}" for col in overlapping})
             else:
                 warnings.warn(
                     "Can't remove view ID prefix from expanded property columns as multiple sources exist",
@@ -1070,7 +1177,7 @@ class NodeList(DataModelingInstancesList[NodeApply, T_Node]):
     def _load_raw_api_response(cls, responses: list[dict[str, Any]], cognite_client: CogniteClient) -> Self:
         typing = next((TypeInformation._load(resp["typing"]) for resp in responses if "typing" in resp), None)
         resources = [
-            cls._RESOURCE._load(item, cognite_client=cognite_client)  # type: ignore[has-type]
+            cls._RESOURCE._load(item, cognite_client=cognite_client)
             for response in responses
             for item in response.get("items", [])
         ]
@@ -1166,7 +1273,7 @@ class EdgeList(DataModelingInstancesList[EdgeApply, T_Edge]):
     def _load_raw_api_response(cls, responses: list[dict[str, Any]], cognite_client: CogniteClient) -> Self:
         typing = next((TypeInformation._load(resp["typing"]) for resp in responses if "typing" in resp), None)
         resources = [
-            cls._RESOURCE._load(item, cognite_client=cognite_client)  # type: ignore[has-type]
+            cls._RESOURCE._load(item, cognite_client=cognite_client)
             for response in responses
             for item in response.get("items", [])
         ]
