@@ -589,7 +589,7 @@ class SequenceUpdate(CogniteUpdate):
             # Sequences do not support setting metadata to an empty array.
             PropertySpec("metadata", is_object=True, is_nullable=False),
             PropertySpec("data_set_id"),
-            # PropertySpec("columns", is_list=True),
+            # Columns are handled separately in the .upsert() method
         ]
 
 
@@ -663,7 +663,7 @@ class SequenceRows(CogniteResource):
         col_length = len(columns)
         if wrong_length := [r for r in rows if len(r.values) != col_length]:
             raise ValueError(
-                f"Rows { [r.row_number for r in wrong_length] } have wrong number of values, expected {col_length}"
+                f"Rows {[r.row_number for r in wrong_length]} have wrong number of values, expected {col_length}"
             )
         self.rows = rows
         self.columns: SequenceColumnList = columns
@@ -842,7 +842,7 @@ class SequenceData(SequenceRows):
         )
 
 
-class SequenceRowsList(CogniteResourceList[SequenceRows]):
+class SequenceRowsList(CogniteResourceList[SequenceRows], IdTransformerMixin):
     _RESOURCE = SequenceRows
 
     def __str__(self) -> str:
