@@ -214,11 +214,11 @@ class TimeSeries(TimeSeriesCore):
         if self.is_string:
             raise RuntimeError("String time series does not support count aggregate.")
 
-        identifier = Identifier.load(self.id, self.external_id).as_dict()
+        identifier = Identifier.load(self.id, self.external_id, self.instance_id).as_dict()
         dps = self._cognite_client.time_series.data.retrieve(
             **identifier, start=MIN_TIMESTAMP_MS, end=MAX_TIMESTAMP_MS + 1, aggregates="count", granularity="100d"
         )
-        return sum(dps.count)  # type: ignore [union-attr, arg-type]
+        return sum(dps.count)
 
     def latest(self, before: int | str | datetime | None = None) -> Datapoint | None:
         """Returns the latest datapoint in this time series. If empty, returns None.
@@ -228,9 +228,9 @@ class TimeSeries(TimeSeriesCore):
         Returns:
             Datapoint | None: A datapoint object containing the value and timestamp of the latest datapoint.
         """
-        identifier = Identifier.load(self.id, self.external_id).as_dict()
+        identifier = Identifier.load(self.id, self.external_id, self.instance_id).as_dict()
         if dps := self._cognite_client.time_series.data.retrieve_latest(**identifier, before=before):
-            return dps[0]  # type: ignore [return-value]
+            return dps[0]
         return None
 
     def first(self) -> Datapoint | None:
@@ -239,12 +239,12 @@ class TimeSeries(TimeSeriesCore):
         Returns:
             Datapoint | None: A datapoint object containing the value and timestamp of the first datapoint.
         """
-        identifier = Identifier.load(self.id, self.external_id).as_dict()
+        identifier = Identifier.load(self.id, self.external_id, self.instance_id).as_dict()
         dps = self._cognite_client.time_series.data.retrieve(
             **identifier, start=MIN_TIMESTAMP_MS, end=MAX_TIMESTAMP_MS + 1, limit=1
         )
         if dps:
-            return dps[0]  # type: ignore [return-value]
+            return dps[0]
         return None
 
     def asset(self) -> Asset:
@@ -349,6 +349,9 @@ class TimeSeriesUpdate(CogniteUpdate):
     def __init__(
         self, id: int | None = None, external_id: str | None = None, instance_id: NodeId | None = None
     ) -> None:
+        if instance_id is not None and (id is not None or external_id is not None):
+            raise ValueError("Exactly one of 'id', 'external_id' or 'instance_id' must be provided.")
+
         super().__init__(id=id, external_id=external_id)
         self.instance_id = instance_id
 
