@@ -1,10 +1,11 @@
 from __future__ import annotations
 
+import warnings
 from abc import ABC, abstractmethod
 from collections import UserList
 from collections.abc import Collection, Sequence
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Any, ClassVar, Literal, TypeAlias, cast
+from typing import TYPE_CHECKING, Any, ClassVar, Literal, TypeAlias, cast, final
 
 from typing_extensions import Self
 
@@ -13,10 +14,16 @@ from cognite.client.data_classes._base import (
     CogniteResource,
     CogniteResourceList,
     ExternalIDTransformerMixin,
+    InternalIdTransformerMixin,
     UnknownCogniteObject,
     WriteableCogniteResource,
     WriteableCogniteResourceList,
 )
+from cognite.client.data_classes.data_modeling.query import Query, ResultSetExpression, Select
+from cognite.client.data_classes.simulators.runs import (
+    SimulationInputOverride,
+)
+from cognite.client.utils._experimental import FeaturePreviewWarning
 from cognite.client.utils._text import convert_all_keys_to_camel_case, to_snake_case
 
 if TYPE_CHECKING:
@@ -37,9 +44,10 @@ WorkflowStatus: TypeAlias = Literal["completed", "failed", "running", "terminate
 
 
 class WorkflowCore(WriteableCogniteResource["WorkflowUpsert"], ABC):
-    def __init__(self, external_id: str, description: str | None) -> None:
+    def __init__(self, external_id: str, description: str | None = None, data_set_id: int | None = None) -> None:
         self.external_id = external_id
         self.description = description
+        self.data_set_id = data_set_id
 
 
 class WorkflowUpsert(WorkflowCore):
@@ -49,13 +57,21 @@ class WorkflowUpsert(WorkflowCore):
     Args:
         external_id (str): The external ID provided by the client. Must be unique for the resource type.
         description (str | None): Description of the workflow. Note that when updating a workflow, the description will
-                            always be overwritten also if it is set to None. Meaning if the wokflow already has a description,
+                            always be overwritten also if it is set to None. Meaning if the workflow already has a description,
                             and you want to keep it, you need to provide the description when updating the workflow.
+        data_set_id (int | None): The id of the data set this workflow belongs to.
+                            If a dataSetId is provided, any operations on this workflow, or its versions, executions,
+                            and triggers will require appropriate access to the data set. More information on data sets
+                            and their configuration can be found here: https://docs.cognite.com/cdf/data_governance/concepts/datasets/
     """
 
     @classmethod
     def _load(cls, resource: dict, cognite_client: CogniteClient | None = None) -> Self:
-        return cls(external_id=resource["externalId"], description=resource.get("description"))
+        return cls(
+            external_id=resource["externalId"],
+            description=resource.get("description"),
+            data_set_id=resource.get("dataSetId"),
+        )
 
     def as_write(self) -> WorkflowUpsert:
         """Returns this workflow instance."""
@@ -64,23 +80,27 @@ class WorkflowUpsert(WorkflowCore):
 
 class Workflow(WorkflowCore):
     """
-    This class represents a workflow. This is the reading version, used when reading or listing a workflows.
+    This class represents a workflow. This is the reading version, used when reading or listing workflows.
 
     Args:
         external_id (str): The external ID provided by the client. Must be unique for the resource type.
         created_time (int): The time when the workflow was created. Unix timestamp in milliseconds.
+        last_updated_time (int): The time when the workflow was last updated. Unix timestamp in milliseconds.
         description (str | None): Description of the workflow. Defaults to None.
-
+        data_set_id (int | None): The id of the data set this workflow belongs to.
     """
 
     def __init__(
         self,
         external_id: str,
         created_time: int,
+        last_updated_time: int,
         description: str | None = None,
+        data_set_id: int | None = None,
     ) -> None:
-        super().__init__(external_id, description)
+        super().__init__(external_id, description, data_set_id)
         self.created_time = created_time
+        self.last_updated_time = last_updated_time
 
     @classmethod
     def _load(cls, resource: dict, cognite_client: CogniteClient | None = None) -> Self:
@@ -88,6 +108,8 @@ class Workflow(WorkflowCore):
             external_id=resource["externalId"],
             description=resource.get("description"),
             created_time=resource["createdTime"],
+            last_updated_time=resource["lastUpdatedTime"],
+            data_set_id=resource.get("dataSetId"),
         )
 
     def as_write(self) -> WorkflowUpsert:
@@ -95,6 +117,7 @@ class Workflow(WorkflowCore):
         return WorkflowUpsert(
             external_id=self.external_id,
             description=self.description,
+            data_set_id=self.data_set_id,
         )
 
 
@@ -112,7 +135,7 @@ class WorkflowList(WriteableCogniteResourceList[WorkflowUpsert, Workflow], Exter
         return WorkflowUpsertList([workflow.as_write() for workflow in self.data])
 
 
-ValidTaskType = Literal["function", "transformation", "cdf", "dynamic", "subworkflow"]
+ValidTaskType = Literal["function", "transformation", "cdf", "dynamic", "subworkflow", "simulation"]
 
 
 class WorkflowTaskParameters(CogniteObject, ABC):
@@ -140,6 +163,8 @@ class WorkflowTaskParameters(CogniteObject, ABC):
             return SubworkflowTaskParameters._load(parameters)
         elif type_ == "subworkflow" and "workflowExternalId" in parameters["subworkflow"]:
             return SubworkflowReferenceParameters._load(parameters)
+        elif type_ == "simulation":
+            return SimulationTaskParameters._load(parameters)
         else:
             raise ValueError(f"Unknown task type: {type_}. Expected {ValidTaskType}")
 
@@ -200,7 +225,7 @@ class FunctionTaskParameters(WorkflowTaskParameters):
         return cls(
             external_id=function["externalId"],
             data=function.get("data"),
-            # API uses isAsyncComplete and asyncComplete inconsistently:
+            # TODO: Fix: API uses isAsyncComplete and asyncComplete inconsistently:
             is_async_complete=resource.get("isAsyncComplete", resource.get("asyncComplete")),
         )
 
@@ -215,10 +240,63 @@ class FunctionTaskParameters(WorkflowTaskParameters):
             "function": function,
         }
         if self.is_async_complete is not None:
-            output[("isAsyncComplete" if camel_case else "is_async_complete")] = self.is_async_complete
+            output["isAsyncComplete" if camel_case else "is_async_complete"] = self.is_async_complete
         return output
 
 
+_SIMULATORS_WARNING = FeaturePreviewWarning(
+    api_maturity="General Availability", sdk_maturity="alpha", feature_name="Simulators"
+)
+
+
+class SimulationTaskParameters(WorkflowTaskParameters):
+    """
+    The simulation parameters are used to specify the simulation routine to be executed.
+    Args:
+        routine_external_id (str): The external ID of the simulation routine to be executed.
+        run_time (int | None): Reference timestamp used for data pre-processing and data sampling.
+        inputs (list[SimulationInputOverride] | None): List of input overrides.
+    """
+
+    task_type = "simulation"
+
+    def __init__(
+        self,
+        routine_external_id: str,
+        run_time: int | None = None,
+        inputs: list[SimulationInputOverride] | None = None,
+    ) -> None:
+        self.routine_external_id = routine_external_id
+        self.run_time = run_time
+        self.inputs = inputs
+
+    def __post_init__(self) -> None:
+        _SIMULATORS_WARNING.warn()
+
+    @classmethod
+    def _load(cls, resource: dict, cognite_client: CogniteClient | None = None) -> SimulationTaskParameters:
+        simulation: dict[str, Any] = resource["simulation"]
+
+        return cls(
+            routine_external_id=simulation["routineExternalId"],
+            run_time=simulation.get("runTime"),
+            inputs=[SimulationInputOverride._load(item) for item in simulation.get("inputs", [])]
+            if simulation.get("inputs")
+            else None,
+        )
+
+    def dump(self, camel_case: bool = True) -> dict[str, Any]:
+        simulation: dict[str, Any] = {
+            "routineExternalId" if camel_case else "routine_external_id": self.routine_external_id,
+        }
+        if self.run_time:
+            simulation["runTime" if camel_case else "run_time"] = self.run_time
+        if self.inputs:
+            simulation["inputs"] = [item.dump(camel_case) for item in self.inputs]
+
+        return {"simulation": simulation}
+
+
 class TransformationTaskParameters(WorkflowTaskParameters):
     """
     The transformation parameters are used to specify the transformation to be called.
@@ -226,30 +304,39 @@ class TransformationTaskParameters(WorkflowTaskParameters):
     Args:
         external_id (str): The external ID of the transformation to be called.
         concurrency_policy (Literal['fail', 'restartAfterCurrent', 'waitForCurrent']): Determines the behavior of the task if the Transformation is already running. ``fail``: The task fails if another instance of the Transformation is currently running. ``waitForCurrent``: The task will pause and wait for the already running Transformation to complete. Once completed, the task is completed. This mode is useful for preventing redundant Transformation runs. ``restartAfterCurrent``: The task waits for the ongoing Transformation to finish. After completion, the task restarts the Transformation. This mode ensures that the most recent data can be used by following tasks.
+        use_transformation_credentials (bool): If set to `true`, the transformation will be run using the client credentials configured on the transformation. If set to `false`, the transformation will be run using the client credentials used to trigger the workflow.
     """
 
     task_type = "transformation"
 
     def __init__(
-        self, external_id: str, concurrency_policy: Literal["fail", "restartAfterCurrent", "waitForCurrent"] = "fail"
+        self,
+        external_id: str,
+        concurrency_policy: Literal["fail", "restartAfterCurrent", "waitForCurrent"] = "fail",
+        use_transformation_credentials: bool = False,
     ) -> None:
         self.external_id = external_id
         self.concurrency_policy = concurrency_policy
+        self.use_transformation_credentials = use_transformation_credentials
 
     @classmethod
     def _load(cls, resource: dict, cognite_client: CogniteClient | None = None) -> TransformationTaskParameters:
         return cls(
-            resource["transformation"]["externalId"],
-            resource["transformation"]["concurrencyPolicy"],
+            resource[cls.task_type]["externalId"],
+            resource[cls.task_type].get("concurrencyPolicy", "fail"),
+            resource[cls.task_type].get("useTransformationCredentials", False),
         )
 
     def dump(self, camel_case: bool = True) -> dict[str, Any]:
         transformation = {
             "externalId" if camel_case else "external_id": self.external_id,
             "concurrencyPolicy" if camel_case else "concurrency_policy": self.concurrency_policy,
+            "useTransformationCredentials"
+            if camel_case
+            else "use_transformation_credentials": self.use_transformation_credentials,
         }
 
-        return {"transformation": transformation}
+        return {self.task_type: transformation}
 
 
 class CDFTaskParameters(WorkflowTaskParameters):
@@ -485,10 +572,13 @@ class WorkflowTask(CogniteResource):
             "externalId" if camel_case else "external_id": self.external_id,
             "type": self.type,
             "parameters": self.parameters.dump(camel_case),
-            "retries": self.retries,
-            "timeout": self.timeout,
-            "onFailure" if camel_case else "on_failure": self.on_failure,
         }
+        if self.retries is not None:
+            output["retries"] = self.retries
+        if self.timeout is not None:
+            output["timeout"] = self.timeout
+        if self.on_failure is not None:
+            output["onFailure" if camel_case else "on_failure"] = self.on_failure
         if self.name:
             output["name"] = self.name
         if self.description:
@@ -521,6 +611,8 @@ class WorkflowTaskOutput(ABC):
             return DynamicTaskOutput.load(data)
         elif task_type == "subworkflow":
             return SubworkflowTaskOutput.load(data)
+        elif task_type == "simulation":
+            return SimulationTaskOutput.load(data)
         else:
             raise ValueError(f"Unknown task type: {task_type}")
 
@@ -560,6 +652,47 @@ class FunctionTaskOutput(WorkflowTaskOutput):
         }
 
 
+class SimulationTaskOutput(WorkflowTaskOutput):
+    """
+    The class represent the output of Simulation execution.
+    Args:
+        run_id (int | None): The run ID of the simulation run.
+        log_id (int | None): The log ID of the simulation run.
+        status_message (str | None): Status message of the simulation execution.
+    """
+
+    task_type: ClassVar[str] = "simulation"
+
+    def __post_init__(self) -> None:
+        _SIMULATORS_WARNING.warn()
+
+    def __init__(
+        self,
+        run_id: int | None,
+        log_id: int | None,
+        status_message: str | None,
+    ) -> None:
+        self.run_id = run_id
+        self.log_id = log_id
+        self.status_message = status_message
+
+    @classmethod
+    def load(cls, data: dict[str, Any]) -> SimulationTaskOutput:
+        output = data["output"]
+        return cls(
+            run_id=output.get("runId"),
+            log_id=output.get("logId"),
+            status_message=output.get("statusMessage"),
+        )
+
+    def dump(self, camel_case: bool = True) -> dict[str, Any]:
+        return {
+            "runId" if camel_case else "run_id": self.run_id,
+            "logId" if camel_case else "log_id": self.log_id,
+            "statusMessage" if camel_case else "status_message": self.status_message,
+        }
+
+
 class TransformationTaskOutput(WorkflowTaskOutput):
     """
     The transformation output is used to specify the output of a transformation task.
@@ -723,14 +856,14 @@ class WorkflowDefinitionCore(WriteableCogniteResource["WorkflowDefinitionUpsert"
         tasks (list[WorkflowTask]): The tasks of the workflow definition.
         description (str | None): The description of the workflow definition. Note that when updating a workflow definition
                             description, it will always be overwritten also if it is set to None. Meaning if the
-                            wokflow definition already has a description, and you want to keep it, you need to provide
+                            workflow definition already has a description, and you want to keep it, you need to provide
                             the description when updating it.
     """
 
     def __init__(
         self,
         tasks: list[WorkflowTask],
-        description: str | None,
+        description: str | None = None,
     ) -> None:
         self.tasks = tasks
         self.description = description
@@ -751,7 +884,7 @@ class WorkflowDefinitionCore(WriteableCogniteResource["WorkflowDefinitionUpsert"
 
 class WorkflowDefinitionUpsert(WorkflowDefinitionCore):
     """
-    This class represents a workflow definition. This represents the write/update version of a workflow definiton.
+    This class represents a workflow definition. This represents the write/update version of a workflow definition.
 
     A workflow definition defines the tasks and order/dependencies of these tasks.
 
@@ -759,14 +892,14 @@ class WorkflowDefinitionUpsert(WorkflowDefinitionCore):
         tasks (list[WorkflowTask]): The tasks of the workflow definition.
         description (str | None): The description of the workflow definition. Note that when updating a workflow definition
                             description, it will always be overwritten also if it is set to None. Meaning if the
-                            wokflow definition already has a description, and you want to keep it, you need to provide
+                            workflow definition already has a description, and you want to keep it, you need to provide
                             the description when updating it.
     """
 
     def __init__(
         self,
         tasks: list[WorkflowTask],
-        description: str | None,
+        description: str | None = None,
     ) -> None:
         super().__init__(tasks, description)
 
@@ -790,7 +923,7 @@ class WorkflowDefinitionUpsert(WorkflowDefinitionCore):
 
 class WorkflowDefinition(WorkflowDefinitionCore):
     """
-    This class represents a workflow definition. This represents the read version of a workflow definiton.
+    This class represents a workflow definition. This represents the read version of a workflow definition.
 
     A workflow definition defines the tasks and order/dependencies of these tasks.
 
@@ -901,6 +1034,8 @@ class WorkflowVersion(WorkflowVersionCore):
         workflow_external_id (str): The external ID of the workflow.
         version (str): The version of the workflow.
         workflow_definition (WorkflowDefinition): The workflow definition of the workflow version.
+        created_time (int): The number of milliseconds since 00:00:00 Thursday, 1 January 1970, Coordinated Universal Time (UTC), minus leap seconds.
+        last_updated_time (int): The number of milliseconds since 00:00:00 Thursday, 1 January 1970, Coordinated Universal Time (UTC), minus leap seconds.
     """
 
     def __init__(
@@ -908,12 +1043,13 @@ class WorkflowVersion(WorkflowVersionCore):
         workflow_external_id: str,
         version: str,
         workflow_definition: WorkflowDefinition,
+        created_time: int,
+        last_updated_time: int,
     ) -> None:
-        super().__init__(
-            workflow_external_id=workflow_external_id,
-            version=version,
-        )
+        super().__init__(workflow_external_id=workflow_external_id, version=version)
         self.workflow_definition = workflow_definition
+        self.created_time = created_time
+        self.last_updated_time = last_updated_time
 
     @classmethod
     def _load(cls, resource: dict, cognite_client: CogniteClient | None = None) -> WorkflowVersion:
@@ -922,13 +1058,17 @@ class WorkflowVersion(WorkflowVersionCore):
             workflow_external_id=resource["workflowExternalId"],
             version=resource["version"],
             workflow_definition=WorkflowDefinition._load(workflow_definition),
+            created_time=resource["createdTime"],
+            last_updated_time=resource["lastUpdatedTime"],
         )
 
     def dump(self, camel_case: bool = True) -> dict[str, Any]:
         return {
-            ("workflowExternalId" if camel_case else "workflow_external_id"): self.workflow_external_id,
+            "workflowExternalId" if camel_case else "workflow_external_id": self.workflow_external_id,
             "version": self.version,
-            ("workflowDefinition" if camel_case else "workflow_definition"): self.workflow_definition.dump(camel_case),
+            "workflowDefinition" if camel_case else "workflow_definition": self.workflow_definition.dump(camel_case),
+            "createdTime" if camel_case else "created_time": self.created_time,
+            "lastUpdatedTime" if camel_case else "last_updated_time": self.last_updated_time,
         }
 
     def as_write(self) -> WorkflowVersionUpsert:
@@ -1005,10 +1145,7 @@ class WorkflowExecution(CogniteResource):
         self.metadata = metadata
 
     def as_workflow_id(self) -> WorkflowVersionId:
-        return WorkflowVersionId(
-            workflow_external_id=self.workflow_external_id,
-            version=self.version,
-        )
+        return WorkflowVersionId(workflow_external_id=self.workflow_external_id, version=self.version)
 
     @classmethod
     def _load(cls, resource: dict, cognite_client: CogniteClient | None = None) -> WorkflowExecution:
@@ -1028,7 +1165,7 @@ class WorkflowExecution(CogniteResource):
         )
 
 
-class WorkflowExecutionList(CogniteResourceList[WorkflowExecution]):
+class WorkflowExecutionList(CogniteResourceList[WorkflowExecution], InternalIdTransformerMixin):
     """
     This class represents a list of workflow executions.
     """
@@ -1142,11 +1279,18 @@ class WorkflowVersionId:
     workflow_external_id: str
     version: str | None = None
 
-    def as_primitive(self) -> tuple[str, str | None]:
+    def as_tuple(self) -> tuple[str, str | None]:
         return self.workflow_external_id, self.version
 
+    def as_primitive(self) -> tuple[str, str | None]:
+        warnings.warn(
+            "as_primitive() is deprecated, use as_tuple instead. Will be removed in the next major release.",
+            DeprecationWarning,
+        )
+        return self.as_tuple()
+
     @classmethod
-    def load(cls, resource: dict, cognite_client: CogniteClient | None = None) -> WorkflowVersionId:
+    def load(cls, resource: dict) -> Self:
         if "workflowExternalId" in resource:
             workflow_external_id = resource["workflowExternalId"]
         elif "externalId" in resource:
@@ -1154,25 +1298,20 @@ class WorkflowVersionId:
         else:
             raise ValueError("Invalid input to WorkflowVersionId.load")
 
-        return cls(
-            workflow_external_id=workflow_external_id,
-            version=resource.get("version"),
-        )
+        return cls(workflow_external_id=workflow_external_id, version=resource.get("version"))
 
     def dump(self, camel_case: bool = True, as_external_id_key: bool = False) -> dict[str, Any]:
         if as_external_id_key:
-            output: dict[str, Any] = {("externalId" if camel_case else "external_id"): self.workflow_external_id}
+            output: dict[str, Any] = {"externalId" if camel_case else "external_id": self.workflow_external_id}
         else:
-            output = {("workflowExternalId" if camel_case else "workflow_external_id"): self.workflow_external_id}
+            output = {"workflowExternalId" if camel_case else "workflow_external_id": self.workflow_external_id}
         if self.version:
             output["version"] = self.version
         return output
 
 
 class WorkflowIds(UserList):
-    """
-    This class represents a list of Workflow Version Identifiers.
-    """
+    """This class represents a list of Workflow Version Identifiers."""
 
     def __init__(self, workflow_ids: Collection[WorkflowVersionId]) -> None:
         for workflow_id in workflow_ids:
@@ -1183,8 +1322,11 @@ class WorkflowIds(UserList):
                 )
         super().__init__(workflow_ids)
 
+    def as_tuples(self) -> list[tuple[str, str | None]]:
+        return [wid.as_tuple() for wid in self]
+
     @classmethod
-    def load(cls, resource: Any, cognite_client: CogniteClient | None = None) -> WorkflowIds:
+    def load(cls, resource: Any) -> Self:
         workflow_ids: Sequence[WorkflowVersionId]
         if isinstance(resource, tuple) and len(resource) == 2 and all(isinstance(x, str) for x in resource):
             workflow_ids = [WorkflowVersionId(*resource)]
@@ -1194,14 +1336,18 @@ class WorkflowIds(UserList):
             workflow_ids = [WorkflowVersionId(workflow_external_id=resource)]
         elif isinstance(resource, dict):
             workflow_ids = [WorkflowVersionId.load(resource)]
-        elif isinstance(resource, Sequence) and resource and isinstance(resource[0], tuple):
-            workflow_ids = [WorkflowVersionId(*x) for x in resource]
-        elif isinstance(resource, Sequence) and resource and isinstance(resource[0], WorkflowVersionId):
-            workflow_ids = resource
-        elif isinstance(resource, Sequence) and resource and isinstance(resource[0], str):
-            workflow_ids = [WorkflowVersionId(workflow_external_id=x) for x in resource]
+        elif isinstance(resource, Sequence) and resource:
+            workflow_ids = []
+            for wf in resource:
+                match wf:
+                    case tuple():
+                        workflow_ids.append(WorkflowVersionId(*wf))
+                    case str():
+                        workflow_ids.append(WorkflowVersionId(workflow_external_id=wf))
+                    case _:
+                        workflow_ids.append(wf)
         else:
-            raise ValueError("Invalid input to WorkflowIds")
+            raise ValueError("Invalid input to WorkflowIds.load")
         return cls(workflow_ids)
 
     def dump(self, camel_case: bool = True, as_external_id: bool = False) -> list[dict[str, Any]]:
@@ -1213,8 +1359,15 @@ class WorkflowTriggerRule(CogniteObject, ABC):
 
     _trigger_type: ClassVar[str]
 
-    def __init__(self) -> None:
-        self.trigger_type = self._trigger_type
+    @final
+    @property
+    def trigger_type(self) -> str:
+        return self._trigger_type
+
+    def dump(self, camel_case: bool = True) -> dict[str, Any]:
+        dumped = super().dump(camel_case)
+        dumped["triggerType" if camel_case else "trigger_type"] = self.trigger_type
+        return dumped
 
     @classmethod
     def _load(cls, resource: dict, cognite_client: CogniteClient | None = None) -> Self:
@@ -1227,7 +1380,33 @@ class WorkflowTriggerRule(CogniteObject, ABC):
     @classmethod
     @abstractmethod
     def _load_trigger(cls, data: dict) -> Self:
-        raise NotImplementedError()
+        raise NotImplementedError
+
+
+class WorkflowTriggerDataModelingQuery(Query):
+    r"""This class represents a data modeling trigger query.
+
+    Args:
+        with_ (dict[str, ResultSetExpression]): A dictionary of result set expressions to use in the query. The keys are used to reference the result set expressions in the select.
+        select (dict[str, Select]): A dictionary of select expressions to use in the query. The keys must match the keys in the with\_ dictionary. The select expressions define which properties to include in the result set.
+    """
+
+    def __init__(
+        self,
+        with_: dict[str, ResultSetExpression],
+        select: dict[str, Select],
+    ) -> None:
+        super().__init__(with_, select)
+        # Parameters and cursors are not supported for workflow trigger queries:
+        self.parameters = None
+        self.cursors = None  # type: ignore [assignment]
+
+    @classmethod
+    def _load(cls, resource: dict, cognite_client: CogniteClient | None = None) -> Self:
+        return cls(
+            with_={k: ResultSetExpression.load(v) for k, v in resource["with"].items()},
+            select={k: Select.load(v) for k, v in resource["select"].items()},
+        )
 
 
 class WorkflowScheduledTriggerRule(WorkflowTriggerRule):
@@ -1235,18 +1414,59 @@ class WorkflowScheduledTriggerRule(WorkflowTriggerRule):
     This class represents a scheduled trigger rule.
 
     Args:
-        cron_expression(str | None): The cron specification for the scheduled trigger.
+        cron_expression (str): The cron specification for the scheduled trigger.
     """
 
     _trigger_type = "schedule"
 
-    def __init__(self, cron_expression: str | None = None) -> None:
-        super().__init__()
+    def __init__(self, cron_expression: str) -> None:
         self.cron_expression = cron_expression
 
     @classmethod
     def _load_trigger(cls, data: dict) -> WorkflowScheduledTriggerRule:
-        return cls(cron_expression=data.get("cronExpression"))
+        return cls(cron_expression=data["cronExpression"])
+
+
+class WorkflowDataModelingTriggerRule(WorkflowTriggerRule):
+    """
+    This class represents a data modeling trigger rule.
+
+    Args:
+        data_modeling_query (WorkflowTriggerDataModelingQuery): The data modeling query of the trigger.
+        batch_size (int | None): The batch size of the trigger.
+        batch_timeout (int | None): The batch timeout of the trigger.
+    """
+
+    _trigger_type = "dataModeling"
+
+    def __init__(
+        self,
+        data_modeling_query: WorkflowTriggerDataModelingQuery,
+        batch_size: int | None = None,
+        batch_timeout: int | None = None,
+    ) -> None:
+        self.data_modeling_query = data_modeling_query
+        self.batch_size = batch_size
+        self.batch_timeout = batch_timeout
+
+    @classmethod
+    def _load_trigger(cls, data: dict) -> WorkflowDataModelingTriggerRule:
+        return cls(
+            data_modeling_query=WorkflowTriggerDataModelingQuery.load(data["dataModelingQuery"]),
+            batch_size=data.get("batchSize"),
+            batch_timeout=data.get("batchTimeout"),
+        )
+
+    def dump(self, camel_case: bool = True) -> dict[str, Any]:
+        item: dict[str, Any] = {
+            "trigger_type": self.trigger_type,
+            "data_modeling_query": self.data_modeling_query.dump(camel_case=camel_case),
+            "batch_size": self.batch_size,
+            "batch_timeout": self.batch_timeout,
+        }
+        if camel_case:
+            return convert_all_keys_to_camel_case(item)
+        return item
 
 
 _TRIGGER_RULE_BY_TYPE: dict[str, type[WorkflowTriggerRule]] = {
@@ -1265,6 +1485,7 @@ class WorkflowTriggerCore(WriteableCogniteResource["WorkflowTriggerUpsert"], ABC
         workflow_external_id (str): The external ID of the workflow.
         workflow_version (str): The version of the workflow.
         input (dict | None): The input data of the workflow version trigger. Defaults to None.
+        metadata (dict | None): Application specific metadata. Defaults to None.
     """
 
     def __init__(
@@ -1274,12 +1495,14 @@ class WorkflowTriggerCore(WriteableCogniteResource["WorkflowTriggerUpsert"], ABC
         workflow_external_id: str,
         workflow_version: str,
         input: dict | None = None,
+        metadata: dict | None = None,
     ) -> None:
         self.external_id = external_id
         self.trigger_rule = trigger_rule
         self.workflow_external_id = workflow_external_id
         self.workflow_version = workflow_version
         self.input = input
+        self.metadata = metadata
 
 
 class WorkflowTriggerUpsert(WorkflowTriggerCore):
@@ -1292,6 +1515,7 @@ class WorkflowTriggerUpsert(WorkflowTriggerCore):
         workflow_external_id (str): The external ID of the workflow.
         workflow_version (str): The version of the workflow.
         input (dict | None): The input data of the workflow version trigger. Defaults to None.
+        metadata (dict | None): Application specific metadata. Defaults to None.
     """
 
     def dump(self, camel_case: bool = True) -> dict[str, Any]:
@@ -1303,6 +1527,8 @@ class WorkflowTriggerUpsert(WorkflowTriggerCore):
         }
         if self.input:
             item["input"] = self.input
+        if self.metadata:
+            item["metadata"] = self.metadata
         if camel_case:
             return convert_all_keys_to_camel_case(item)
         return item
@@ -1315,6 +1541,7 @@ class WorkflowTriggerUpsert(WorkflowTriggerCore):
             workflow_version=resource["workflowVersion"],
             trigger_rule=WorkflowTriggerRule._load(resource["triggerRule"]),
             input=resource.get("input"),
+            metadata=resource.get("metadata"),
         )
 
     def as_write(self) -> WorkflowTriggerUpsert:
@@ -1335,6 +1562,7 @@ class WorkflowTrigger(WorkflowTriggerCore):
         workflow_external_id (str): The external ID of the workflow.
         workflow_version (str): The version of the workflow.
         input (dict | None): The input data passed to the workflow when an execution is started. Defaults to None.
+        metadata (dict | None): Application specific metadata. Defaults to None.
         created_time (int | None): The time when the workflow version trigger was created. Unix timestamp in milliseconds. Defaults to None.
         last_updated_time (int | None): The time when the workflow version trigger was last updated. Unix timestamp in milliseconds. Defaults to None.
     """
@@ -1346,6 +1574,7 @@ class WorkflowTrigger(WorkflowTriggerCore):
         workflow_external_id: str,
         workflow_version: str,
         input: dict | None = None,
+        metadata: dict | None = None,
         created_time: int | None = None,
         last_updated_time: int | None = None,
     ) -> None:
@@ -1355,6 +1584,7 @@ class WorkflowTrigger(WorkflowTriggerCore):
             workflow_external_id=workflow_external_id,
             workflow_version=workflow_version,
             input=input,
+            metadata=metadata,
         )
         self.created_time = created_time
         self.last_updated_time = last_updated_time
@@ -1368,6 +1598,8 @@ class WorkflowTrigger(WorkflowTriggerCore):
         }
         if self.input:
             item["input"] = self.input
+        if self.metadata:
+            item["metadata"] = self.metadata
         if self.created_time:
             item["created_time"] = self.created_time
         if self.last_updated_time:
@@ -1384,6 +1616,7 @@ class WorkflowTrigger(WorkflowTriggerCore):
             workflow_version=resource["workflowVersion"],
             trigger_rule=WorkflowTriggerRule._load(resource["triggerRule"]),
             input=resource.get("input"),
+            metadata=resource.get("metadata"),
             created_time=resource.get("createdTime"),
             last_updated_time=resource.get("lastUpdatedTime"),
         )
@@ -1396,14 +1629,17 @@ class WorkflowTrigger(WorkflowTriggerCore):
             workflow_external_id=self.workflow_external_id,
             workflow_version=self.workflow_version,
             input=self.input,
+            metadata=self.metadata,
         )
 
 
-class WorkflowTriggerUpsertList(CogniteResourceList[WorkflowTriggerUpsert]):
+class WorkflowTriggerUpsertList(CogniteResourceList[WorkflowTriggerUpsert], ExternalIDTransformerMixin):
     _RESOURCE = WorkflowTriggerUpsert
 
 
-class WorkflowTriggerList(WriteableCogniteResourceList[WorkflowTriggerUpsert, WorkflowTrigger]):
+class WorkflowTriggerList(
+    WriteableCogniteResourceList[WorkflowTriggerUpsert, WorkflowTrigger], ExternalIDTransformerMixin
+):
     """
     This class represents a list of workflow triggers.
     """
@@ -1467,9 +1703,7 @@ class WorkflowTriggerRun(CogniteResource):
         )
 
 
-class WorkflowTriggerRunList(CogniteResourceList[WorkflowTriggerRun]):
-    """
-    This class represents a list of workflow trigger runs.
-    """
+class WorkflowTriggerRunList(CogniteResourceList[WorkflowTriggerRun], ExternalIDTransformerMixin):
+    """This class represents a list of workflow trigger runs."""
 
     _RESOURCE = WorkflowTriggerRun
